@@ -1,6 +1,7 @@
-# pyresample, Resampling of remote sensing image data in python
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 #
-# Copyright (C) 2010, 2013, 2015  Esben S. Nielsen, Martin Raspaud
+# Copyright (C) 2010-2021 Pyresample developers
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -14,42 +15,41 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Multiprocessing versions of KDTree and Proj classes."""
 
 from __future__ import absolute_import
 
 import ctypes
+import multiprocessing as mp
 
 import numpy as np
 import pyproj
-#import scipy.spatial as sp
-import multiprocessing as mp
 
 try:
     import numexpr as ne
 except ImportError:
     ne = None
 
-from ._multi_proc import shmem_as_ndarray, Scheduler
+from ._multi_proc import Scheduler, shmem_as_ndarray
 
 # Earth radius
 R = 6370997.0
 
 
 class cKDTree_MP(object):
-
-    ''' Multiprocessing cKDTree subclass, shared memory '''
+    """Multiprocessing cKDTree subclass, shared memory."""
 
     def __init__(self, data, leafsize=10, nprocs=2, chunk=None,
                  schedule='guided'):
-        '''
-        Same as cKDTree.__init__ except that an internal copy
-        of data to shared memory is made.
+        """Prepare shared memory for KDTree operations.
+
+        Same as cKDTree.__init__ except that an internal copy of data to shared memory is made.
+
         Extra keyword arguments:
         chunk : Minimum chunk size for the load balancer.
         schedule: Strategy for balancing work load
         ('static', 'dynamic' or 'guided').
-        '''
-
+        """
         self.n, self.m = data.shape
         # Allocate shared memory for data
         self.shmem_data = mp.RawArray(ctypes.c_double, self.n * self.m)
@@ -58,7 +58,7 @@ class cKDTree_MP(object):
         # The RawArray objects have information about the dtype and
         # buffer size.
         _data = shmem_as_ndarray(self.shmem_data).reshape((self.n, self.m))
-        _data[:,:] = data
+        _data[:, :] = data
 
         # Initialize parent, we must do this last because
         # cKDTree stores a reference to the data array. We pass in
@@ -69,11 +69,7 @@ class cKDTree_MP(object):
         self._schedule = schedule
 
     def query(self, x, k=1, eps=0, p=2, distance_upper_bound=np.inf):
-        '''
-        Same as cKDTree.query except parallelized with multiple
-        processes and shared memory.        
-        '''
-
+        """Query for points at index 'x' parallelized with multiple processes and shared memory."""
         # allocate shared memory for x and result
         nx = x.shape[0]
         shmem_x = mp.RawArray(ctypes.c_double, nx * self.m)
@@ -106,26 +102,41 @@ class cKDTree_MP(object):
         return _d.copy(), _i.copy()
 
 
-class Proj(pyproj.Proj):
+class BaseProj(pyproj.Proj):
+    """Helper class for easier backwards compatibility."""
+
+    def __init__(self, projparams=None, preserve_units=True, **kwargs):
+        # have to have this because pyproj uses __new__
+        # subclasses would fail when calling __init__ otherwise
+        super(BaseProj, self).__init__(projparams=projparams,
+                                       preserve_units=preserve_units,
+                                       **kwargs)
+
+
+class Proj(BaseProj):
+    """Helper class to skip transforming lon/lat projection coordinates."""
 
     def __call__(self, data1, data2, inverse=False, radians=False,
                  errcheck=False, nprocs=1):
-        if self.is_latlong():
+        """Transform coordinates to coordinate system except for geographic coordinate systems."""
+        if self.crs.is_geographic:
             return data1, data2
-
         return super(Proj, self).__call__(data1, data2, inverse=inverse,
                                           radians=radians, errcheck=errcheck)
 
 
-class Proj_MP(pyproj.Proj):
+class Proj_MP(BaseProj):
+    """Multi-processing version of the pyproj Proj class."""
 
     def __init__(self, *args, **kwargs):
         self._args = args
         self._kwargs = kwargs
+        super(Proj_MP, self).__init__(*args, **kwargs)
 
     def __call__(self, data1, data2, inverse=False, radians=False,
                  errcheck=False, nprocs=2, chunk=None, schedule='guided'):
-        if self.is_latlong():
+        """Transform coordinates to coordinates in the current coordinate system."""
+        if self.crs.is_geographic:
             return data1, data2
 
         grid_shape = data1.shape
@@ -160,37 +171,39 @@ class Proj_MP(pyproj.Proj):
 
 
 class Cartesian(object):
+    """Cartesian coordinates."""
 
     def __init__(self, *args, **kwargs):
         pass
 
     def transform_lonlats(self, lons, lats):
-
+        """Transform longitudes and latitues to cartesian coordinates."""
+        if np.issubdtype(lons.dtype, np.integer):
+            lons = lons.astype(np.float64)
         coords = np.zeros((lons.size, 3), dtype=lons.dtype)
-        deg2rad = lons.dtype.type(np.pi / 180)
         if ne:
+            deg2rad = np.pi / 180  # noqa: F841
             coords[:, 0] = ne.evaluate("R*cos(lats*deg2rad)*cos(lons*deg2rad)")
             coords[:, 1] = ne.evaluate("R*cos(lats*deg2rad)*sin(lons*deg2rad)")
             coords[:, 2] = ne.evaluate("R*sin(lats*deg2rad)")
         else:
-            coords[:, 0] = R * np.cos(lats * deg2rad) * np.cos(lons * deg2rad)
-            coords[:, 1] = R * np.cos(lats * deg2rad) * np.sin(lons * deg2rad)
-            coords[:, 2] = R * np.sin(lats * deg2rad)
+            coords[:, 0] = R * np.cos(np.deg2rad(lats)) * np.cos(np.deg2rad(lons))
+            coords[:, 1] = R * np.cos(np.deg2rad(lats)) * np.sin(np.deg2rad(lons))
+            coords[:, 2] = R * np.sin(np.deg2rad(lats))
         return coords
 
+
 Cartesian_MP = Cartesian
 
 
 def _run_jobs(target, args, nprocs):
-    """Run process pool
-    """
-
+    """Run process pool."""
     # return status in shared memory
     # access to these values are serialized automatically
     ierr = mp.Value(ctypes.c_int, 0)
-    err_msg = mp.Array(ctypes.c_char, 1024)
+    warn_msg = mp.Array(ctypes.c_char, 1024)
 
-    args.extend((ierr, err_msg))
+    args.extend((ierr, warn_msg))
 
     pool = [mp.Process(target=target, args=args) for n in range(nprocs)]
     for p in pool:
@@ -199,7 +212,7 @@ def _run_jobs(target, args, nprocs):
         p.join()
     if ierr.value != 0:
         raise RuntimeError('%d errors in worker processes. Last one reported:\n%s' %
-                           (ierr.value, err_msg.value.decode()))
+                           (ierr.value, warn_msg.value.decode()))
 
 # This is executed in an external process:
 
@@ -209,7 +222,7 @@ def _parallel_query(scheduler,  # scheduler for load balancing
                     data, ndata, ndim, leafsize,
                     x, nx, d, i,  # query data and results
                     k, eps, p, dub,  # auxillary query parameters
-                    ierr, err_msg):  # return values (0 on success)
+                    ierr, warn_msg):  # return values (0 on success)
 
     try:
         # View shared memory as ndarrays.
@@ -230,20 +243,20 @@ def _parallel_query(scheduler,  # scheduler for load balancing
         # from the load balancer.
         for s in scheduler:
             if k == 1:
-                _d[s], _i[s] = kdtree.query(_x[s,:], k=1, eps=eps, p=p,\
+                _d[s], _i[s] = kdtree.query(_x[s, :], k=1, eps=eps, p=p,
                                             distance_upper_bound=dub)
             else:
-                _d[s,:], _i[s,:] = kdtree.query(_x[s,:], k=k, eps=eps, p=p,\
-                                                distance_upper_bound=dub)
+                _d[s, :], _i[s, :] = kdtree.query(_x[s, :], k=k, eps=eps, p=p,
+                                                  distance_upper_bound=dub)
     # An error occured, increment the return value ierr.
     # Access to ierr is serialized by multiprocessing.
     except Exception as e:
         ierr.value += 1
-        err_msg.value = str(e).encode()
+        warn_msg.value = str(e).encode()
 
 
 def _parallel_proj(scheduler, data1, data2, res1, res2, proj_args, proj_kwargs,
-                   inverse, radians, errcheck, ierr, err_msg):
+                   inverse, radians, errcheck, ierr, warn_msg):
     try:
         # View shared memory as ndarrays.
         _data1 = shmem_as_ndarray(data1)
@@ -263,10 +276,10 @@ def _parallel_proj(scheduler, data1, data2, res1, res2, proj_args, proj_kwargs,
     # Access to ierr is serialized by multiprocessing.
     except Exception as e:
         ierr.value += 1
-        err_msg.value = str(e).encode()
+        warn_msg.value = str(e).encode()
 
 
-def _parallel_transform(scheduler, lons, lats, n, coords, ierr, err_msg):
+def _parallel_transform(scheduler, lons, lats, n, coords, ierr, warn_msg):
     try:
         # View shared memory as ndarrays.
         _lons = shmem_as_ndarray(lons)
@@ -284,4 +297,4 @@ def _parallel_transform(scheduler, lons, lats, n, coords, ierr, err_msg):
     # Access to ierr is serialized by multiprocessing.
     except Exception as e:
         ierr.value += 1
-        err_msg.value = str(e).encode()
+        warn_msg.value = str(e).encode()
