@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2019 Pyresample developers
+# Copyright (C) 2019-2021 Pyresample developers
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -15,13 +15,21 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Area config handling and creation utilities."""
+
+import io
 import logging
 import math
 import os
+import pathlib
+import warnings
+from typing import Any, Union
 
 import numpy as np
-import six
 import yaml
+from pyproj import Proj, Transformer
+from pyproj.crs import CRS, CRSError
+
 from pyresample.utils import proj4_str_to_dict
 
 try:
@@ -31,22 +39,25 @@ except ImportError:
         """Stand-in for DataArray for holding units information."""
 
         def __init__(self, data, attrs=None):
+            """Initialize 'attrs' and 'data' properties."""
             self.attrs = attrs or {}
             self.data = np.array(data)
 
         def __getitem__(self, item):
+            """Get a subset of the data contained in a DataArray."""
             return DataArray(self.data[item], attrs=self.attrs)
 
         def __getattr__(self, item):
+            """Get metadata property from 'attrs'."""
             return self.attrs[item]
 
         def __len__(self):
+            """Get size of the data."""
             return len(self.data)
 
 
 class AreaNotFound(KeyError):
     """Exception raised when specified are is no found in file."""
-    pass
 
 
 def load_area(area_file_name, *regions):
@@ -54,8 +65,11 @@ def load_area(area_file_name, *regions):
 
     Parameters
     ----------
-    area_file_name : str or list
-        One or more paths to area definition files
+    area_file_name : str, pathlib.Path, stream, or list thereof
+        List of paths or streams.  Any str or pathlib.Path will be
+        interpreted as a path to a file.  Any stream will be interpreted
+        as containing a yaml definition file.  To read directly from a string,
+        use :func:`load_area_from_string`.
     regions : str argument list
         Regions to parse. If no regions are specified all
         regions in the file are returned
@@ -71,15 +85,39 @@ def load_area(area_file_name, *regions):
     AreaNotFound:
         If a specified area name is not found
     """
-
     area_list = parse_area_file(area_file_name, *regions)
     if len(area_list) == 1:
         return area_list[0]
     return area_list
 
 
+def load_area_from_string(area_strs, *regions):
+    """Load area(s) from area strings.
+
+    Like :func:`~pyresample.area_config.load_area`, but load from string
+    directly.
+
+    Parameters
+    ----------
+    area_strs : str or List[str]
+        Strings containing yaml definitions.
+    regions : str
+        Regions to parse.
+
+    Returns
+    -------
+    area_defs : AreaDefinition or list
+        If one area name is specified a single AreaDefinition object is returned.
+        If several area names are specified a list of AreaDefinition objects is returned
+    """
+    if isinstance(area_strs, str):
+        area_strs = [area_strs]
+    return load_area([io.StringIO(area_str) for area_str in area_strs],
+                     *regions)
+
+
 def parse_area_file(area_file_name, *regions):
-    """Parse area information from area file
+    """Parse area information from area file.
 
     Parameters
     -----------
@@ -99,7 +137,6 @@ def parse_area_file(area_file_name, *regions):
     AreaNotFound:
         If a specified area is not found
     """
-
     try:
         return _parse_yaml_area_file(area_file_name, *regions)
     except (yaml.scanner.ScannerError, yaml.parser.ParserError):
@@ -109,17 +146,29 @@ def parse_area_file(area_file_name, *regions):
 def _read_yaml_area_file_content(area_file_name):
     """Read one or more area files in to a single dict object."""
     from pyresample.utils import recursive_dict_update
-    if isinstance(area_file_name, (str, six.text_type)):
+
+    if isinstance(area_file_name, (str, pathlib.Path)):
         area_file_name = [area_file_name]
 
     area_dict = {}
     for area_file_obj in area_file_name:
-        if (isinstance(area_file_obj, (str, six.text_type)) and
-                os.path.isfile(area_file_obj)):
-            with open(area_file_obj) as area_file_obj:
-                tmp_dict = yaml.safe_load(area_file_obj)
-        else:
+        if isinstance(area_file_obj, io.IOBase):
+            # already a stream
             tmp_dict = yaml.safe_load(area_file_obj)
+        else:
+            # hopefully a path to a file, but in the past a yaml string could
+            # be passed directly, assume any string with a newline must be
+            # a yaml file and not a path
+            if isinstance(area_file_obj, str) and "\n" in area_file_obj:
+                warnings.warn("It looks like you passed a YAML string "
+                              "directly.  This is deprecated since pyresample "
+                              "1.14.1, please use load_area_from_string or "
+                              "pass a stream or a path to a file instead",
+                              DeprecationWarning)
+                tmp_dict = yaml.safe_load(area_file_obj)
+            else:
+                with open(area_file_obj) as area_file_obj:
+                    tmp_dict = yaml.safe_load(area_file_obj)
         area_dict = recursive_dict_update(area_dict, tmp_dict)
 
     return area_dict
@@ -159,7 +208,7 @@ def _parse_yaml_area_file(area_file_name, *regions):
 
 
 def _capture_subarguments(params, arg_name, sub_arg_list):
-    """Captures :func:`~pyresample.utils.create_area_def` sub-arguments (i.e. units, height, dx, etc) from a yaml file.
+    """Capture :func:`~pyresample.utils.create_area_def` sub-arguments (i.e. units, height, dx, etc) from a yaml file.
 
     Example:
         resolution:
@@ -204,17 +253,17 @@ def _capture_subarguments(params, arg_name, sub_arg_list):
 
 
 def _read_legacy_area_file_lines(area_file_name):
-    if isinstance(area_file_name, (str, six.text_type)):
+    if isinstance(area_file_name, str):
         area_file_name = [area_file_name]
 
     for area_file_obj in area_file_name:
-        if (isinstance(area_file_obj, (str, six.text_type)) and
+        if (isinstance(area_file_obj, str) and
            not os.path.isfile(area_file_obj)):
             # file content string
             for line in area_file_obj.splitlines():
                 yield line
             continue
-        elif isinstance(area_file_obj, (str, six.text_type)):
+        elif isinstance(area_file_obj, str):
             # filename
             with open(area_file_obj, 'r') as area_file:
                 for line in area_file.readlines():
@@ -265,7 +314,7 @@ def _parse_legacy_area_file(area_file_name, *regions):
 
 
 def _create_area(area_id, area_content):
-    """Parse area configuration"""
+    """Parse area configuration."""
     from configobj import ConfigObj
     config_obj = area_content.replace('{', '').replace('};', '')
     config_obj = ConfigObj([line.replace(':', '=', 1)
@@ -299,7 +348,7 @@ def _create_area(area_id, area_content):
 
 
 def get_area_def(area_id, area_name, proj_id, proj4_args, width, height, area_extent, rotation=0):
-    """Construct AreaDefinition object from arguments
+    """Construct AreaDefinition object from arguments.
 
     Parameters
     -----------
@@ -325,7 +374,6 @@ def get_area_def(area_id, area_name, proj_id, proj4_args, width, height, area_ex
     area_def : object
         AreaDefinition object
     """
-
     proj_dict = _get_proj4_args(proj4_args)
     return create_area_def(area_id, proj_dict, description=area_name, proj_id=proj_id,
                            shape=(height, width), area_extent=area_extent)
@@ -333,8 +381,8 @@ def get_area_def(area_id, area_name, proj_id, proj4_args, width, height, area_ex
 
 def _get_proj4_args(proj4_args):
     """Create dict from proj4 args."""
-    from pyresample.utils._proj4 import convert_proj_floats
-    if isinstance(proj4_args, (str, six.text_type)):
+    from pyresample.utils.proj4 import convert_proj_floats
+    if isinstance(proj4_args, str):
         # float conversion is done in `proj4_str_to_dict` already
         return proj4_str_to_dict(str(proj4_args))
 
@@ -345,14 +393,16 @@ def _get_proj4_args(proj4_args):
 
 def create_area_def(area_id, projection, width=None, height=None, area_extent=None, shape=None, upper_left_extent=None,
                     center=None, resolution=None, radius=None, units=None, **kwargs):
-    """Takes data the user knows and tries to make an area definition from what can be found.
+    """Create AreaDefinition from whatever information is known.
 
     Parameters
     ----------
     area_id : str
         ID of area
-    projection : dict or str
-        Projection parameters as a proj4_dict or proj4_string
+    projection : pyproj CRS object, dict, str, int, tuple, object
+        Projection parameters.  This can be in any format understood by
+        :func:`pyproj.crs.CRS.from_user_input`, such as a pyproj CRS object,
+        proj4 dict, proj4 string, EPSG integer code, or others.
     description : str, optional
         Description/name of area. Defaults to area_id
     proj_id : str, optional
@@ -414,7 +464,6 @@ def create_area_def(area_id, projection, width=None, height=None, area_extent=No
       they represent [projection x distance from center[0] to center[0]+dx, projection y distance from center[1] to
       center[1]+dy]
     """
-    from pyresample._spatial_mp import Proj
     description = kwargs.pop('description', area_id)
     proj_id = kwargs.pop('proj_id', None)
 
@@ -423,16 +472,16 @@ def create_area_def(area_id, projection, width=None, height=None, area_extent=No
     if isinstance(projection, dict) and 'EPSG' in projection:
         projection = "EPSG:{}".format(projection['EPSG'])
 
-    # Get a proj4_dict from either a proj4_dict or a proj4_string.
-    proj_dict = _get_proj_data(projection)
     try:
-        p = Proj(projection, preserve_units=True)
-    except RuntimeError:
+        crs = _get_proj_data(projection)
+        p = Proj(crs, preserve_units=True)
+    except (RuntimeError, CRSError):
+        # Assume that an invalid projection will be "fixed" by a dynamic area definition later
         return _make_area(area_id, description, proj_id, projection, shape, area_extent, **kwargs)
 
     # If no units are provided, try to get units used in proj_dict. If still none are provided, use meters.
     if units is None:
-        units = proj_dict.get('units', 'm' if not p.is_latlong() else 'degrees')
+        units = _get_proj_units(crs)
 
     # Allow height and width to be provided for more consistency across functions in pyresample.
     if height is not None or width is not None:
@@ -447,14 +496,14 @@ def create_area_def(area_id, projection, width=None, height=None, area_extent=No
     area_extent = _verify_list('area_extent', area_extent, 4)
 
     # Converts from lat/lon to projection coordinates (x,y) if not in projection coordinates. Returns tuples.
-    center = _convert_units(center, 'center', units, p, proj_dict)
-    upper_left_extent = _convert_units(upper_left_extent, 'upper_left_extent', units, p, proj_dict)
+    center = _convert_units(center, 'center', units, p, crs)
+    upper_left_extent = _convert_units(upper_left_extent, 'upper_left_extent', units, p, crs)
     if area_extent is not None:
         # convert area extent, pass as (X, Y)
         area_extent_ll = area_extent[:2]
         area_extent_ur = area_extent[2:]
-        area_extent_ll = _convert_units(area_extent_ll, 'area_extent', units, p, proj_dict)
-        area_extent_ur = _convert_units(area_extent_ur, 'area_extent', units, p, proj_dict)
+        area_extent_ll = _convert_units(area_extent_ll, 'area_extent', units, p, crs)
+        area_extent_ur = _convert_units(area_extent_ur, 'area_extent', units, p, crs)
         area_extent = area_extent_ll + area_extent_ur
 
     # Fills in missing information to attempt to create an area definition.
@@ -462,15 +511,22 @@ def create_area_def(area_id, projection, width=None, height=None, area_extent=No
         area_extent, shape, resolution = \
             _extrapolate_information(area_extent, shape, center, radius,
                                      resolution, upper_left_extent, units,
-                                     p, proj_dict)
+                                     p, crs)
     return _make_area(area_id, description, proj_id, projection, shape,
                       area_extent, resolution=resolution, **kwargs)
 
 
-def _make_area(area_id, description, proj_id, proj_dict, shape, area_extent, **kwargs):
-    """Handles the creation of an area definition for create_area_def."""
-    from pyresample.geometry import AreaDefinition
-    from pyresample.geometry import DynamicAreaDefinition
+def _make_area(
+        area_id: str,
+        description: str,
+        proj_id: str,
+        projection: Union[dict, CRS],
+        shape: tuple,
+        area_extent: tuple,
+        **kwargs):
+    """Handle the creation of an area definition for create_area_def."""
+    from pyresample.geometry import AreaDefinition, DynamicAreaDefinition
+
     # Remove arguments that are only for DynamicAreaDefinition.
     optimize_projection = kwargs.pop('optimize_projection', False)
     resolution = kwargs.pop('resolution', None)
@@ -480,38 +536,44 @@ def _make_area(area_id, description, proj_id, proj_dict, shape, area_extent, **k
     if shape is not None:
         height, width = shape
     if None not in (area_extent, shape):
-        return AreaDefinition(area_id, description, proj_id, proj_dict, width, height, area_extent, **kwargs)
+        return AreaDefinition(area_id, description, proj_id, projection, width, height, area_extent, **kwargs)
 
-    return DynamicAreaDefinition(area_id=area_id, description=description, projection=proj_dict, width=width,
+    return DynamicAreaDefinition(area_id=area_id, description=description, projection=projection, width=width,
                                  height=height, area_extent=area_extent, rotation=kwargs.get('rotation'),
                                  resolution=resolution, optimize_projection=optimize_projection)
 
 
-def _get_proj_data(projection):
-    """Takes a proj4_dict or proj4_string and returns a proj4_dict and a Proj function.
+def _get_proj_data(projection: Any) -> CRS:
+    """Take projection information and returns a proj CRS.
 
-    There is special handling for the "EPSG:XXXX" case where "XXXX" is an
-    EPSG number code. It can be provided as a string `"EPSG:XXXX"` or as a
-    dictionary (when provided via YAML) as `{'EPSG': XXXX}`.
+    Takes projection information in any format understood by
+    :func:`pyproj.crs.CRS.from_user_input`.  There is special
+    handling for the "EPSG:XXXX" case where "XXXX" is an EPSG
+    number code. It can be provided as a string `"EPSG:XXXX"` or
+    as a dictionary (when provided via YAML) as `{'EPSG': XXXX}`.
     If it is passed as a string ("EPSG:XXXX") then the rules of
-    :func:`~pyresample.utils._proj.proj4_str_to_dict` are followed.
-    If a dictionary and pyproj 2.0+ is installed then the string
-    `"EPSG:XXXX"` is passed to ``proj4_str_to_dict``. If pyproj<2.0
-    is installed then the string ``+init=EPSG:XXXX`` is passed to
-    ``proj4_str_to_dict`` which provides limited information to area
-    config operations.
-
+    :func:`~pyresample.utils._proj.proj4_str_to_dict` are followed.  If a
+    dictionary and pyproj 2.0+ is installed then the string `"EPSG:XXXX"`
+    is passed to ``proj4_str_to_dict``. If pyproj<2.0 is installed then
+    the string ``+init=EPSG:XXXX`` is passed to ``proj4_str_to_dict``
+    which provides limited information to area config operations.
     """
     if isinstance(projection, dict) and 'EPSG' in projection:
         projection = "EPSG:{}".format(projection['EPSG'])
+    return CRS.from_user_input(projection)
 
-    if isinstance(projection, str):
-        proj_dict = proj4_str_to_dict(projection)
-    elif isinstance(projection, dict):
-        proj_dict = projection
+
+def _get_proj_units(crs):
+    if crs.is_geographic:
+        unit_name = 'degrees'
     else:
-        raise TypeError('Wrong type for projection: {0}. Expected dict or string.'.format(type(projection)))
-    return proj_dict
+        unit_name = crs.axis_info[0].unit_name
+    return {
+        'metre': 'm',
+        'meter': 'm',
+        'kilometre': 'km',
+        'kilometer': 'km',
+    }.get(unit_name, unit_name)
 
 
 def _sign(num):
@@ -519,7 +581,6 @@ def _sign(num):
 
     Returns:
         1 if number is greater than 0, -1 otherwise
-
     """
     return -1 if num < 0 else 1
 
@@ -528,7 +589,6 @@ def _round_poles(center, units, p):
     """Round center to the nearest pole if it is extremely close to said pole.
 
     Used to work around floating point precision issues .
-
     """
     # For a laea projection, this allows for an error of 11 meters around the pole.
     error = .0001
@@ -543,7 +603,10 @@ def _round_poles(center, units, p):
     return center
 
 
-def _distance_from_center_forward(var, center, p):
+def _distance_from_center_forward(
+        var: tuple,
+        center: tuple,
+        p: Proj):
     """Convert distances in degrees to projection units."""
     # Interprets radius and resolution as distances between latitudes/longitudes.
     # Since the distance between longitudes and latitudes is not constant in
@@ -554,7 +617,7 @@ def _distance_from_center_forward(var, center, p):
     center_as_angle = p(*center, inverse=True, errcheck=True)
     pole = 90
     # If on a pole, use northern/southern latitude for both height and width.
-    if abs(abs(center_as_angle[1]) - pole) < 1e-8:
+    if abs(abs(center_as_angle[1]) - pole) < 1e-3:
         direction_of_poles = _sign(center_as_angle[1])
         var = (center[1] - p(0, center_as_angle[1] - direction_of_poles * abs(var[0]),
                              errcheck=True)[1],
@@ -568,20 +631,24 @@ def _distance_from_center_forward(var, center, p):
     return var
 
 
-def _convert_units(var, name, units, p, proj_dict, inverse=False, center=None):
-    """Converts units from lon/lat to projection coordinates (meters).
+def _convert_units(
+        var,
+        name: str,
+        units: str,
+        p: Proj,
+        crs: CRS,
+        inverse: bool = False,
+        center=None):
+    """Convert units from lon/lat to projection coordinates (meters).
 
     If `inverse` it True then the inverse calculation is done.
-
     """
-    from pyproj import transform
-    from pyresample._spatial_mp import Proj
     if var is None:
         return None
     if isinstance(var, DataArray):
         units = var.units
         var = tuple(var.data.tolist())
-    if p.is_latlong() and not ('deg' == units or 'degrees' == units):
+    if crs.is_geographic and not ('deg' == units or 'degrees' == units):
         raise ValueError('latlon/latlong projection cannot take {0} as units: {1}'.format(units, name))
     # Check if units are an angle.
     is_angle = ('deg' == units or 'degrees' == units)
@@ -591,10 +658,11 @@ def _convert_units(var, name, units, p, proj_dict, inverse=False, center=None):
     if not is_angle:
         if units == 'meters' or units == 'metres':
             units = 'm'
-        if proj_dict.get('units', 'm') != units:
-            tmp_proj_dict = proj_dict.copy()
+        if _get_proj_units(crs) != units:
+            tmp_proj_dict = crs.to_dict()
             tmp_proj_dict['units'] = units
-            var = transform(Proj(tmp_proj_dict, preserve_units=True), p, *var)
+            transformer = Transformer.from_crs(tmp_proj_dict, p.crs)
+            var = transformer.transform(*var)
     if name == 'center':
         var = _round_poles(var, units, p)
     # Return either degrees or meters depending on if the inverse is true or not.
@@ -603,7 +671,10 @@ def _convert_units(var, name, units, p, proj_dict, inverse=False, center=None):
     if is_angle and not inverse:
         if name in ('radius', 'resolution'):
             var = _distance_from_center_forward(var, center, p)
-        else:
+        elif not crs.is_geographic:
+            # only convert to meters
+            # this allows geographic projections to use coordinates outside
+            # normal lon/lat ranges (ex. -90/90)
             var = p(*var, errcheck=True)
     # Don't convert if inverse is False: Want meters.
     elif not is_angle and inverse:
@@ -618,9 +689,8 @@ def _round_shape(shape, radius=None, resolution=None):
     """Make sure shape is an integer.
 
     Rounds down if shape is less than .01 above nearest whole number to
-    handle floating point precision issues. Otherwise the number is round
-    up.
-
+    handle floating point precision issues. Otherwise the number is
+    round up.
     """
     # Used for area definition to prevent indexing None.
     if shape is None:
@@ -650,26 +720,24 @@ def _round_shape(shape, radius=None, resolution=None):
 
 
 def _validate_variable(var, new_var, var_name, input_list):
-    """Makes sure data given by the user does not conflict with itself.
+    """Make sure data given by the user does not conflict with itself.
 
     If a variable that was given by the user contradicts other data provided, an exception is raised.
     Example: upper_left_extent is (-10, 10), but area_extent is (-20, -20, 20, 20).
-
     """
     if var is not None and not np.allclose(np.array(var, dtype=float), np.array(new_var, dtype=float), equal_nan=True):
         raise ValueError('CONFLICTING DATA: {0} given does not match {0} found from {1}'.format(
-            var_name, ', '.join(input_list)) + ':\ngiven: {0}\nvs\nfound: {1}'.format(var, new_var, var_name,
-                                                                                      input_list))
+            var_name, ', '.join(input_list)) + ':\ngiven: {0}\nvs\nfound: {1}'.format(var, new_var))
     return new_var
 
 
-def _extrapolate_information(area_extent, shape, center, radius, resolution, upper_left_extent, units, p, proj_dict):
-    """Attempts to find shape and area_extent based on data provided.
+def _extrapolate_information(area_extent, shape, center, radius, resolution, upper_left_extent, units, p, crs):
+    """Attempt to find shape and area_extent based on data provided.
 
     Parameters are used in a specific order to determine area_extent and shape.
     The area_extent and shape are later used to create an `AreaDefinition`.
     Providing some parameters may have no effect if other parameters could be
-    to used determine area_extent and shape. The order of the parameters used
+    used to determine area_extent and shape. The order of the parameters used
     is:
 
     1. area_extent
@@ -678,7 +746,6 @@ def _extrapolate_information(area_extent, shape, center, radius, resolution, upp
     4. resolution and shape
     5. radius and center
     6. upper_left_extent and radius
-
     """
     # Input unaffected by data below: When area extent is calculated, it's either with
     # shape (giving you an area definition) or with center/radius/upper_left_extent (which this produces).
@@ -688,7 +755,7 @@ def _extrapolate_information(area_extent, shape, center, radius, resolution, upp
         new_center = ((area_extent[2] + area_extent[0]) / 2, (area_extent[3] + area_extent[1]) / 2)
         center = _validate_variable(center, new_center, 'center', ['area_extent'])
         # If radius is given in an angle without center it will raise an exception, and to verify, it must be in meters.
-        radius = _convert_units(radius, 'radius', units, p, proj_dict, center=center)
+        radius = _convert_units(radius, 'radius', units, p, crs, center=center)
         new_radius = ((area_extent[2] - area_extent[0]) / 2, (area_extent[3] - area_extent[1]) / 2)
         radius = _validate_variable(radius, new_radius, 'radius', ['area_extent'])
         new_upper_left_extent = (area_extent[0], area_extent[3])
@@ -697,13 +764,13 @@ def _extrapolate_information(area_extent, shape, center, radius, resolution, upp
     # Output used below, but nowhere else is upper_left_extent made. Thus it should go as early as possible.
     elif None not in (upper_left_extent, center):
         # Function 1-B
-        radius = _convert_units(radius, 'radius', units, p, proj_dict, center=center)
+        radius = _convert_units(radius, 'radius', units, p, crs, center=center)
         new_radius = (center[0] - upper_left_extent[0], upper_left_extent[1] - center[1])
         radius = _validate_variable(radius, new_radius, 'radius', ['upper_left_extent', 'center'])
     else:
-        radius = _convert_units(radius, 'radius', units, p, proj_dict, center=center)
+        radius = _convert_units(radius, 'radius', units, p, crs, center=center)
     # Convert resolution to meters if given as an angle. If center is not found, an exception is raised.
-    resolution = _convert_units(resolution, 'resolution', units, p, proj_dict, center=center)
+    resolution = _convert_units(resolution, 'resolution', units, p, crs, center=center)
     # Inputs unaffected by data below: area_extent is not an input. However, output is used below.
     if radius is not None and resolution is not None:
         # Function 2-A
@@ -730,9 +797,10 @@ def _extrapolate_information(area_extent, shape, center, radius, resolution, upp
 
 
 def _format_list(var, name):
-    """Used to let resolution and radius be single numbers if their elements are equal.
+    """Ensure that parameter is list-like of numbers.
+
+    Used to let resolution and radius be single numbers if their elements are equal.
 
-    Also makes sure that data is list-like and contains only numbers.
     """
     # Single-number format.
     if not isinstance(var, (list, tuple)) and name in ('resolution', 'radius'):
@@ -745,7 +813,7 @@ def _format_list(var, name):
 
 
 def _verify_list(name, var, length):
-    """Checks that list-like variables are list-like, shapes are accurate, and values are numbers."""
+    """Check that list-like variables are list-like, shapes are accurate, and values are numbers."""
     # Make list-like data into tuples (or leave as xarrays). If not list-like, throw a ValueError unless it is None.
     if var is None:
         return None
@@ -756,7 +824,7 @@ def _verify_list(name, var, length):
             var = DataArray(list(_format_list(var.data.tolist(), name)), attrs=var.attrs)
         elif isinstance(var, DataArray):
             if name == 'shape':
-                logging.warning("{0} is unitless, but was passed as a DataArray".format(name, var.attrs))
+                logging.warning("{0} is unitless, but was passed as a DataArray".format(name))
             else:
                 logging.warning("{0} is a DataArray but does not have the attribute 'units',"
                                 "but instead has attribute(s): {1}".format(name, var.attrs))
