@@ -26,25 +26,24 @@
 
 import warnings
 
-from xarray import DataArray, Dataset
 import dask.array as da
-from dask import delayed
 import numpy as np
 import zarr
+from dask import delayed
+from xarray import DataArray, Dataset
 
-from pyresample._spatial_mp import Proj
 from pyresample import CHUNK_SIZE
+from pyresample._spatial_mp import Proj
 from pyresample.bilinear._base import (
     BilinearBase,
     array_slice_for_multiple_arrays,
     find_indices_outside_min_and_max,
-    mask_coordinates,
     get_slicer,
+    get_valid_indices_from_lonlat_boundaries,
     is_swath_to_grid_or_grid_to_grid,
-    lonlat2xyz,
-    get_valid_indices_from_lonlat_boundaries
+    mask_coordinates,
 )
-
+from pyresample.future.resamplers._transform_utils import lonlat2xyz
 
 CACHE_INDICES = ['bilinear_s',
                  'bilinear_t',
@@ -172,7 +171,7 @@ class XArrayBilinearResampler(BilinearBase):
                                    self._radius_of_influence)
         input_coords = lonlat2xyz(source_lons, source_lats)
         valid_input_index = np.ravel(valid_input_index)
-        input_coords = input_coords[valid_input_index, :].astype(np.float)
+        input_coords = input_coords[valid_input_index, :].astype(np.float64)
 
         return da.compute(valid_input_index, input_coords)
 
@@ -201,7 +200,7 @@ class XArrayBilinearResampler(BilinearBase):
 
 def _get_output_xy(target_geo_def):
     out_x, out_y = target_geo_def.get_proj_coords(chunks=CHUNK_SIZE)
-    return da.compute(np.ravel(out_x),  np.ravel(out_y))
+    return da.compute(np.ravel(out_x), np.ravel(out_y))
 
 
 def _get_input_xy(source_geo_def, proj, valid_input_index, index_array):
@@ -232,8 +231,8 @@ def _get_valid_input_index(source_geo_def,
     source_lons, source_lats = _get_raveled_lonlats(source_geo_def)
 
     valid_input_index = da.invert(
-        find_indices_outside_min_and_max(source_lons, -180., 180.)
-        | find_indices_outside_min_and_max(source_lats, -90., 90.))
+        find_indices_outside_min_and_max(source_lons, -180., 180.) |
+        find_indices_outside_min_and_max(source_lats, -90., 90.))
 
     if reduce_data and is_swath_to_grid_or_grid_to_grid(source_geo_def, target_geo_def):
         valid_input_index &= get_valid_indices_from_lonlat_boundaries(
