@@ -1,6 +1,7 @@
-# pyresample, Resampling of remote sensing image data in python
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
 #
-# Copyright (C) 2010, 2015  Martin Raspaud
+# Copyright (C) 2010-2021 Pyresample developers
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -14,33 +15,27 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-
-"""Classes for spherical geometry operations"""
+"""Classes for spherical geometry operations."""
 
 from __future__ import absolute_import
 
 import math
-import numpy as np
 import warnings
 
+import numpy as np
+
 warnings.warn("This module will be removed in pyresample 2.0, please use the "
               "`pyresample.spherical` module functions and class instead.",
               DeprecationWarning)
 
-try:
-    range = xrange
-except NameError:
-    pass
-
 EPSILON = 0.0000001
 
 # FIXME: this has not been tested with R != 1
 
 
 class Coordinate(object):
+    """Point on earth in terms of lat and lon."""
 
-    """Point on earth in terms of lat and lon.
-    """
     lat = None
     lon = None
     x__ = None
@@ -64,21 +59,18 @@ class Coordinate(object):
             self._update_lonlat()
 
     def _update_cart(self):
-        """Convert lon/lat to cartesian coordinates.
-        """
-
+        """Convert lon/lat to cartesian coordinates."""
         self.x__ = math.cos(self.lat) * math.cos(self.lon)
         self.y__ = math.cos(self.lat) * math.sin(self.lon)
         self.z__ = math.sin(self.lat)
 
     def _update_lonlat(self):
-        """Convert cartesian to lon/lat.
-        """
-
+        """Convert cartesian to lon/lat."""
         self.lat = math.degrees(math.asin(self.z__ / self.R__))
         self.lon = math.degrees(math.atan2(self.y__, self.x__))
 
     def __ne__(self, other):
+        """Check inequality."""
         if(abs(self.lat - other.lat) < EPSILON and
            abs(self.lon - other.lon) < EPSILON):
             return 0
@@ -86,18 +78,19 @@ class Coordinate(object):
             return 1
 
     def __eq__(self, other):
+        """Check equality."""
         return not self.__ne__(other)
 
     def __str__(self):
+        """Get simplified representation of lon/lats in degrees."""
         return str((math.degrees(self.lon), math.degrees(self.lat)))
 
     def __repr__(self):
+        """Get simplified representation of lon/lats in degrees."""
         return str((math.degrees(self.lon), math.degrees(self.lat)))
 
     def cross2cart(self, point):
-        """Compute the cross product, and convert to cartesian coordinates
-        (assuming radius 1).
-        """
+        """Compute the cross product, and convert to cartesian coordinates (assuming radius 1)."""
         lat1 = self.lat
         lon1 = self.lon
         lat2 = point.lat
@@ -115,8 +108,7 @@ class Coordinate(object):
         return res
 
     def distance(self, point):
-        """Vincenty formula.
-        """
+        """Get distance using Vincenty formula."""
         dlambda = self.lon - point.lon
         num = ((math.cos(point.lat) * math.sin(dlambda)) ** 2 +
                (math.cos(self.lat) * math.sin(point.lat) -
@@ -128,14 +120,11 @@ class Coordinate(object):
         return math.atan2(math.sqrt(num), den)
 
     def norm(self):
-        """Return the norm of the vector.
-        """
+        """Return the norm of the vector."""
         return math.sqrt(self.x__ ** 2 + self.y__ ** 2 + self.z__ ** 2)
 
     def normalize(self):
-        """normalize the vector.
-        """
-
+        """Normalize the vector."""
         norm = self.norm()
         self.x__ /= norm
         self.y__ /= norm
@@ -144,8 +133,7 @@ class Coordinate(object):
         return self
 
     def cross(self, point):
-        """cross product with another vector.
-        """
+        """Get cross product with another vector."""
         x__ = self.y__ * point.z__ - self.z__ * point.y__
         y__ = self.z__ * point.x__ - self.x__ * point.z__
         z__ = self.x__ * point.y__ - self.y__ * point.x__
@@ -153,26 +141,20 @@ class Coordinate(object):
         return Coordinate(x__=x__, y__=y__, z__=z__)
 
     def dot(self, point):
-        """dot product with another vector.
-        """
+        """Get dot product with another vector."""
         return (self.x__ * point.x__ +
                 self.y__ * point.y__ +
                 self.z__ * point.z__)
 
 
 class Arc(object):
-
-    """An arc of the great circle between two points.
-    """
-    start = None
-    end = None
+    """An arc of the great circle between two points."""
 
     def __init__(self, start, end):
         self.start, self.end = start, end
 
     def center_angle(self):
-        """Angle of an arc at the center of the sphere.
-        """
+        """Get angle of an arc at the center of the sphere."""
         val = (math.cos(self.start.lat - self.end.lat) +
                math.cos(self.start.lon - self.end.lon) - 1)
 
@@ -184,22 +166,25 @@ class Arc(object):
         return math.acos(val)
 
     def __eq__(self, other):
-        if(self.start == other.start and self.end == other.end):
+        """Check equality."""
+        if self.start == other.start and self.end == other.end:
             return 1
         return 0
 
     def __ne__(self, other):
+        """Check inequality."""
         return not self.__eq__(other)
 
     def __str__(self):
+        """Get simplified representation."""
         return str((str(self.start), str(self.end)))
 
     def angle(self, other_arc, snap=True):
-        """Oriented angle between two arcs.
+        """Get oriented angle between two arcs.
 
         Parameters
         ----------
-        other_arc : Arc
+        other_arc : pyresample.spherical_geometry.Arc
         snap : boolean
             Snap small angles to 0. Allows for detecting colinearity. Disable
             snapping when calculating polygon areas as it might lead to
@@ -250,9 +235,7 @@ class Arc(object):
             return angle
 
     def intersections(self, other_arc):
-        """Gives the two intersections of the greats circles defined by the
-       current arc and *other_arc*.
-        """
+        """Get the two intersections of the greats circles defined by the current arc and *other_arc*."""
         if self.end.lon - self.start.lon > math.pi:
             self.end.lon -= 2 * math.pi
         if other_arc.end.lon - other_arc.start.lon > math.pi:
@@ -274,15 +257,16 @@ class Arc(object):
                            math.degrees(-lat)))
 
     def intersects(self, other_arc):
-        """Says if two arcs defined by the current arc and the *other_arc*
-        intersect. An arc is defined as the shortest tracks between two points.
+        """Determine if this arc and another arc intersect.
+
+        An arc is defined as the shortest tracks between two points.
         """
         return bool(self.intersection(other_arc))
 
     def intersection(self, other_arc):
-        """Says where, if two arcs defined by the current arc and the
-        *other_arc* intersect. An arc is defined as the shortest tracks between
-        two points.
+        """Determine the intersection point between this arc and another.
+
+        An arc is defined as the shortest tracks between two points.
         """
         for i in self.intersections(other_arc):
             a__ = self.start
@@ -300,14 +284,12 @@ class Arc(object):
 
 
 def modpi(val):
-    """Puts *val* between -pi and pi.
-    """
+    """Put *val* between -pi and pi."""
     return (val + math.pi) % (2 * math.pi) - math.pi
 
 
 def get_polygon_area(corners):
-    """Get the area of the convex area defined by *corners*.
-    """
+    """Get the area of the convex area defined by *corners*."""
     # We assume the earth is spherical !!!
     # Should be the radius of the earth at the observed position
     R = 1
@@ -328,7 +310,9 @@ def get_polygon_area(corners):
 
 def get_intersections(b__, boundaries):
     """Get the intersections of *b__* with *boundaries*.
-    Returns both the intersection coordinates and the concerned boundaries.
+
+    Returns both the intersection coordinates and the concerned
+    boundaries.
     """
     intersections = []
     bounds = []
@@ -341,8 +325,7 @@ def get_intersections(b__, boundaries):
 
 
 def get_first_intersection(b__, boundaries):
-    """Get the first intersection on *b__* with *boundaries*.
-    """
+    """Get the first intersection on *b__* with *boundaries*."""
     intersections, bounds = get_intersections(b__, boundaries)
     del bounds
     dists = np.array([b__.start.distance(p__) for p__ in intersections])
@@ -353,9 +336,7 @@ def get_first_intersection(b__, boundaries):
 
 
 def get_next_intersection(p__, b__, boundaries):
-    """Get the next intersection from the intersection of arcs *p__* and *b__*
-    along segment *b__* with *boundaries*.
-    """
+    """Get the next intersection from the intersection of arcs *p__* and *b__* along segment *b__* with *boundaries*."""
     new_b = Arc(p__, b__.end)
     intersections, bounds = get_intersections(new_b, boundaries)
     dists = np.array([b__.start.distance(p2) for p2 in intersections])
@@ -368,8 +349,9 @@ def get_next_intersection(p__, b__, boundaries):
 
 
 def point_inside(point, corners):
-    """Is a point inside the 4 corners ? This uses great circle arcs as area
-    boundaries.
+    """Determine if points are inside 4 corner points.
+
+    This uses great circle arcs as area boundaries.
     """
     arc1 = Arc(corners[0], corners[1])
     arc2 = Arc(corners[1], corners[2])
@@ -392,8 +374,7 @@ def point_inside(point, corners):
 
 
 def intersection_polygon(area_corners, segment_corners):
-    """Get the intersection polygon between two areas.
-    """
+    """Get the intersection polygon between two areas."""
     area_boundaries = [Arc(area_corners[0], area_corners[1]),
                        Arc(area_corners[1], area_corners[2]),
                        Arc(area_corners[2], area_corners[3]),
