@@ -1,24 +1,33 @@
-from __future__ import with_statement
-
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+#
+# Copyright (c) 2021 Pyresample developers
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test kd_tree operations."""
 import os
-import sys
-import six
+import unittest
+from unittest import mock
 
 import numpy as np
 
 from pyresample import geometry, kd_tree, utils
 from pyresample.test.utils import catch_warnings
 
-import unittest
-
-try:
-    from unittest import mock
-except ImportError:
-    # python 2.7
-    import mock
-
 
 class Test(unittest.TestCase):
+    """Test nearest neighbor resampling on numpy arrays."""
 
     @classmethod
     def setUpClass(cls):
@@ -119,7 +128,7 @@ class Test(unittest.TestCase):
         data = np.fromfunction(lambda y, x: y * x, (50, 10))
         lons = np.fromfunction(lambda y, x: 3 + x, (50, 10))
         lats = np.fromfunction(lambda y, x: 75 - y, (50, 10))
-        mask = np.ones_like(lons, dtype=np.bool)
+        mask = np.ones_like(lons, dtype=np.bool_)
         mask[::2, ::2] = False
         swath_def = geometry.SwathDefinition(
             lons=np.ma.masked_array(lons, mask=mask),
@@ -339,8 +348,7 @@ class Test(unittest.TestCase):
         expected_stddev = [0.44621800779801657, 0.44363137712896705,
                            0.43861019464274459]
         expected_counts = 4934802.0
-        self.assertTrue(res.shape == stddev.shape and stddev.shape ==
-                        counts.shape and counts.shape == (800, 800, 3))
+        self.assertTrue(res.shape == stddev.shape and stddev.shape == counts.shape and counts.shape == (800, 800, 3))
         self.assertAlmostEqual(cross_sum, expected)
 
         for i, e_stddev in enumerate(expected_stddev):
@@ -631,6 +639,30 @@ class Test(unittest.TestCase):
         expected = 15874591.0
         self.assertEqual(cross_sum, expected)
 
+    def test_nearest_from_sample_np_dtypes(self):
+        lons = np.fromfunction(lambda y, x: 3 + x, (50, 10))
+        lats = np.fromfunction(lambda y, x: 75 - y, (50, 10))
+        swath_def = geometry.SwathDefinition(lons=lons, lats=lats)
+        valid_input_index, valid_output_index, index_array, distance_array = \
+            kd_tree.get_neighbour_info(swath_def,
+                                       self.area_def,
+                                       50000, neighbours=1, segments=1)
+
+        for dtype in [np.uint16, np.float32]:
+            with self.subTest(dtype):
+                data = np.fromfunction(lambda y, x: y * x, (50, 10)).astype(dtype)
+                fill_value = dtype(0.0)
+                res = \
+                    kd_tree.get_sample_from_neighbour_info('nn', (800, 800),
+                                                           data.ravel(),
+                                                           valid_input_index,
+                                                           valid_output_index,
+                                                           index_array,
+                                                           fill_value=fill_value)
+                cross_sum = res.sum()
+                expected = 15874591.0
+                self.assertEqual(cross_sum, expected)
+
     def test_custom_multi_from_sample(self):
         def wf1(dist):
             return 1 - dist / 100000.0
@@ -718,8 +750,8 @@ class TestXArrayResamplerNN(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        import xarray as xr
         import dask.array as da
+        import xarray as xr
         cls.area_def = geometry.AreaDefinition('areaD',
                                                'Europe (3km, HRV, VTC)',
                                                'areaD',
@@ -791,9 +823,10 @@ class TestXArrayResamplerNN(unittest.TestCase):
 
     def test_nearest_swath_1d_mask_to_grid_1n(self):
         """Test 1D swath definition to 2D grid definition; 1 neighbor."""
-        from pyresample.kd_tree import XArrayResamplerNN
-        import xarray as xr
         import dask.array as da
+        import xarray as xr
+
+        from pyresample.kd_tree import XArrayResamplerNN
         resampler = XArrayResamplerNN(self.tswath_1d, self.tgrid,
                                       radius_of_influence=100000,
                                       neighbours=1)
@@ -816,9 +849,10 @@ class TestXArrayResamplerNN(unittest.TestCase):
 
     def test_nearest_type_preserve(self):
         """Test 1D swath definition to 2D grid definition; 1 neighbor."""
-        from pyresample.kd_tree import XArrayResamplerNN
-        import xarray as xr
         import dask.array as da
+        import xarray as xr
+
+        from pyresample.kd_tree import XArrayResamplerNN
         resampler = XArrayResamplerNN(self.tswath_1d, self.tgrid,
                                       radius_of_influence=100000,
                                       neighbours=1)
@@ -844,9 +878,10 @@ class TestXArrayResamplerNN(unittest.TestCase):
 
     def test_nearest_swath_2d_mask_to_area_1n(self):
         """Test 2D swath definition to 2D area definition; 1 neighbor."""
-        from pyresample.kd_tree import XArrayResamplerNN
-        import xarray as xr
         import dask.array as da
+        import xarray as xr
+
+        from pyresample.kd_tree import XArrayResamplerNN
         swath_def = self.swath_def_2d
         data = self.data_2d
         resampler = XArrayResamplerNN(swath_def, self.area_def,
@@ -866,14 +901,17 @@ class TestXArrayResamplerNN(unittest.TestCase):
 
     def test_nearest_area_2d_to_area_1n(self):
         """Test 2D area definition to 2D area definition; 1 neighbor."""
-        from pyresample.kd_tree import XArrayResamplerNN
-        import xarray as xr
         import dask.array as da
+        import xarray as xr
+
+        from pyresample.kd_tree import XArrayResamplerNN
+        from pyresample.test.utils import assert_maximum_dask_computes
         data = self.data_2d
         resampler = XArrayResamplerNN(self.src_area_2d, self.area_def,
                                       radius_of_influence=50000,
                                       neighbours=1)
-        ninfo = resampler.get_neighbour_info()
+        with assert_maximum_dask_computes(0):
+            ninfo = resampler.get_neighbour_info()
         for val in ninfo[:3]:
             # vii, ia, voi
             self.assertIsInstance(val, da.Array)
@@ -882,7 +920,8 @@ class TestXArrayResamplerNN(unittest.TestCase):
 
         # rename data dimensions to match the expected area dimensions
         data = data.rename({'my_dim_y': 'y', 'my_dim_x': 'x'})
-        res = resampler.get_sample_from_neighbour_info(data)
+        with assert_maximum_dask_computes(0):
+            res = resampler.get_sample_from_neighbour_info(data)
         self.assertIsInstance(res, xr.DataArray)
         self.assertIsInstance(res.data, da.Array)
         res = res.values
@@ -892,9 +931,10 @@ class TestXArrayResamplerNN(unittest.TestCase):
 
     def test_nearest_area_2d_to_area_1n_no_roi(self):
         """Test 2D area definition to 2D area definition; 1 neighbor, no radius of influence."""
-        from pyresample.kd_tree import XArrayResamplerNN
-        import xarray as xr
         import dask.array as da
+        import xarray as xr
+
+        from pyresample.kd_tree import XArrayResamplerNN
         data = self.data_2d
         resampler = XArrayResamplerNN(self.src_area_2d, self.area_def,
                                       neighbours=1)
@@ -912,7 +952,7 @@ class TestXArrayResamplerNN(unittest.TestCase):
         self.assertIsInstance(res.data, da.Array)
         res = res.values
         cross_sum = np.nansum(res)
-        expected = 32114793.0
+        expected = 87281406.0
         self.assertEqual(cross_sum, expected)
 
         # pretend the resolutions can't be determined
@@ -933,9 +973,10 @@ class TestXArrayResamplerNN(unittest.TestCase):
 
     def test_nearest_area_2d_to_area_1n_3d_data(self):
         """Test 2D area definition to 2D area definition; 1 neighbor, 3d data."""
-        from pyresample.kd_tree import XArrayResamplerNN
-        import xarray as xr
         import dask.array as da
+        import xarray as xr
+
+        from pyresample.kd_tree import XArrayResamplerNN
         data = self.data_3d
         resampler = XArrayResamplerNN(self.src_area_2d, self.area_def,
                                       radius_of_influence=50000,
@@ -952,7 +993,7 @@ class TestXArrayResamplerNN(unittest.TestCase):
         res = resampler.get_sample_from_neighbour_info(data)
         self.assertIsInstance(res, xr.DataArray)
         self.assertIsInstance(res.data, da.Array)
-        six.assertCountEqual(self, res.coords['bands'], ['r', 'g', 'b'])
+        self.assertCountEqual(res.coords['bands'], ['r', 'g', 'b'])
         res = res.values
         cross_sum = np.nansum(res)
         expected = 83120259.0
@@ -961,9 +1002,10 @@ class TestXArrayResamplerNN(unittest.TestCase):
     @unittest.skipIf(True, "Multiple neighbors not supported yet")
     def test_nearest_swath_1d_mask_to_grid_8n(self):
         """Test 1D swath definition to 2D grid definition; 8 neighbors."""
-        from pyresample.kd_tree import XArrayResamplerNN
-        import xarray as xr
         import dask.array as da
+        import xarray as xr
+
+        from pyresample.kd_tree import XArrayResamplerNN
         resampler = XArrayResamplerNN(self.tswath_1d, self.tgrid,
                                       radius_of_influence=100000,
                                       neighbours=8)
@@ -978,17 +1020,3 @@ class TestXArrayResamplerNN(unittest.TestCase):
         # actual = res.values
         # expected = TODO
         # np.testing.assert_allclose(actual, expected)
-
-
-def suite():
-    """The test suite."""
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(Test))
-    mysuite.addTest(loader.loadTestsFromTestCase(TestXArrayResamplerNN))
-
-    return mysuite
-
-
-if __name__ == '__main__':
-    unittest.main()
