@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf8
 #
-# Copyright (C) 2014-2019 PyTroll developers
+# Copyright (C) 2014-2020 PyTroll developers
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -18,19 +18,11 @@
 """Test the quicklook plotting functions."""
 
 import os
-import numpy as np
 import sys
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
+from unittest import mock
 
-if sys.version_info < (3,):
-    from mock import patch
-    import mock
-else:
-    from unittest.mock import patch
-    from unittest import mock
+import numpy as np
 
 try:
     import matplotlib
@@ -44,13 +36,13 @@ except ImportError:
     Basemap = None
 
 
-MERIDIANS1 = np.array([-180, -170, -160, -150, -140, -130, -120, -110, -100,  -90,  -80,
-                       -70,  -60,  -50,  -40,  -30,  -20,  -10,    0,   10,   20,   30,
-                       40,   50,   60,   70,   80,   90,  100,  110,  120,  130,  140,
-                       150,  160,  170,  180], dtype=np.int64)
+MERIDIANS1 = np.array([-180, -170, -160, -150, -140, -130, -120, -110, -100, -90, -80,
+                       -70, -60, -50, -40, -30, -20, -10, 0, 10, 20, 30,
+                       40, 50, 60, 70, 80, 90, 100, 110, 120, 130, 140,
+                       150, 160, 170, 180], dtype=np.int64)
 
-PARALLELS1 = np.array([-90, -80, -70, -60, -50, -40, -30, -20, -10,   0,  10,  20,  30,
-                       40,  50,  60,  70,  80,  90], dtype=np.int64)
+PARALLELS1 = np.array([-90, -80, -70, -60, -50, -40, -30, -20, -10, 0, 10, 20, 30,
+                       40, 50, 60, 70, 80, 90], dtype=np.int64)
 
 
 class Test(unittest.TestCase):
@@ -86,15 +78,14 @@ class Test(unittest.TestCase):
     @unittest.skipIf(Basemap is None, "basemap is not available")
     def test_area_def2basemap(self):
         """Test the area to Basemap object conversion function."""
-        from pyresample import plot
-        from pyresample import parse_area_file
+        from pyresample import parse_area_file, plot
         area_def = parse_area_file(os.path.join(os.path.dirname(__file__), 'test_files', 'areas.yaml'), 'ease_sh')[0]
         bmap = plot.area_def2basemap(area_def)
         self.assertTrue(bmap.rmajor == bmap.rminor and bmap.rmajor == 6371228.0,
                         'Failed to create Basemap object')
 
-    @patch('matplotlib.ticker.FixedLocator')
-    @patch('matplotlib.pyplot.axes')
+    @mock.patch('matplotlib.ticker.FixedLocator')
+    @mock.patch('matplotlib.pyplot.axes')
     def test_add_gridlines(self, axes, fx_locator):
         """Test the adding of gridlines to matplotlib plotting."""
         from pyresample.plot import _add_gridlines
@@ -128,8 +119,10 @@ class Test(unittest.TestCase):
 
     def test_translate_coast_res(self):
         """Test the translation of coast resolution arguments from old basemap notation to cartopy."""
-        from pyresample.plot import _translate_coast_resolution_to_cartopy
-        from pyresample.plot import BASEMAP_NOT_CARTOPY
+        from pyresample.plot import (
+            BASEMAP_NOT_CARTOPY,
+            _translate_coast_resolution_to_cartopy,
+        )
 
         with self.assertRaises(KeyError) as raises:
             if sys.version_info > (3,):
@@ -164,8 +157,7 @@ class Test(unittest.TestCase):
 
     def test_plate_carreeplot(self):
         """Test the Plate Caree plotting functionality."""
-        from pyresample import plot, kd_tree, geometry
-        from pyresample import parse_area_file
+        from pyresample import geometry, kd_tree, parse_area_file, plot
         area_def = parse_area_file(os.path.join(os.path.dirname(__file__), 'test_files', 'areas.yaml'), 'pc_world')[0]
         swath_def = geometry.SwathDefinition(self.lons, self.lats)
         result = kd_tree.resample_nearest(swath_def, self.tb37v, area_def,
@@ -178,8 +170,7 @@ class Test(unittest.TestCase):
 
     def test_easeplot(self):
         """Test the plotting on the ease grid area."""
-        from pyresample import plot, kd_tree, geometry
-        from pyresample import parse_area_file
+        from pyresample import geometry, kd_tree, parse_area_file, plot
         area_def = parse_area_file(os.path.join(os.path.dirname(__file__), 'test_files', 'areas.yaml'), 'ease_sh')[0]
         swath_def = geometry.SwathDefinition(self.lons, self.lats)
         result = kd_tree.resample_nearest(swath_def, self.tb37v, area_def,
@@ -189,20 +180,10 @@ class Test(unittest.TestCase):
 
     def test_orthoplot(self):
         """Test the ortho plotting."""
-        from pyresample import plot, kd_tree, geometry
-        from pyresample import parse_area_file
+        from pyresample import geometry, kd_tree, parse_area_file, plot
         area_def = parse_area_file(os.path.join(os.path.dirname(__file__), 'test_files', 'areas.cfg'), 'ortho')[0]
         swath_def = geometry.SwathDefinition(self.lons, self.lats)
         result = kd_tree.resample_nearest(swath_def, self.tb37v, area_def,
                                           radius_of_influence=20000,
                                           fill_value=None)
         plot._get_quicklook(area_def, result)
-
-
-def suite():
-    """Test the pyresample easy quicklook plotting functions."""
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(Test))
-
-    return mysuite
