@@ -1,21 +1,35 @@
-from __future__ import with_statement
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+#
+# Copyright (c) 2014-2021 Pyresample developers
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test spherical geometry operations."""
+import math
+import unittest
 
 import numpy as np
-import unittest
-import math
 
-from pyresample.spherical_geometry import Coordinate, Arc
 from pyresample import geometry
+from pyresample.spherical_geometry import Arc, Coordinate
 
 
 class TestOverlap(unittest.TestCase):
-
-    """Testing overlapping functions in pyresample.
-    """
+    """Testing overlapping functions in pyresample."""
 
     def assert_raises(self, exception, call_able, *args):
-        """assertRaises() has changed from py2.6 to 2.7! Here is an attempt to
-        cover both"""
+        """Cover assertRaises from both py2.6 and 2.7+."""
         import sys
         if sys.version_info < (2, 7):
             self.assertRaises(exception, call_able, *args)
@@ -24,8 +38,7 @@ class TestOverlap(unittest.TestCase):
                 call_able(*args)
 
     def test_inside(self):
-        """Testing if a point is inside an area.
-        """
+        """Testing if a point is inside an area."""
         lons = np.array([[-11, 11], [-11, 11]])
         lats = np.array([[11, 11], [-11, -11]])
         area = geometry.SwathDefinition(lons, lats)
@@ -63,8 +76,7 @@ class TestOverlap(unittest.TestCase):
         self.assertTrue(point in area)
 
     def test_overlaps(self):
-        """Test if two areas overlap.
-        """
+        """Test if two areas overlap."""
         lons1 = np.array([[0, 90], [-90, 180]])
         lats1 = np.array([[89, 89], [89, 89]])
         area1 = geometry.SwathDefinition(lons1, lats1)
@@ -110,9 +122,7 @@ class TestOverlap(unittest.TestCase):
         self.assertFalse(area2.overlaps(area1))
 
     def test_overlap_rate(self):
-        """Test how much two areas overlap.
-        """
-
+        """Test how much two areas overlap."""
         lons1 = np.array([[-1, 1], [-1, 1]])
         lats1 = np.array([[1, 1], [-1, -1]])
         area1 = geometry.SwathDefinition(lons1, lats1)
@@ -156,14 +166,10 @@ class TestOverlap(unittest.TestCase):
 
 
 class TestSphereGeometry(unittest.TestCase):
-
-    """Testing sphere geometry from this module.
-    """
+    """Testing sphere geometry from this module."""
 
     def test_angle(self):
-        """Testing the angle value between two arcs.
-        """
-
+        """Testing the angle value between two arcs."""
         base = 0
 
         p0_ = Coordinate(base, base)
@@ -304,8 +310,7 @@ class TestSphereGeometry(unittest.TestCase):
                                msg="this should be -pi/4")
 
     def test_intersects(self):
-        """Test if two arcs intersect.
-        """
+        """Test if two arcs intersect."""
         p0_ = Coordinate(0, 0)
         p1_ = Coordinate(0, 1)
         p2_ = Coordinate(1, 0)
@@ -409,18 +414,3 @@ class TestSphereGeometry(unittest.TestCase):
         self.assertFalse(arc45.intersects(arc02))
 
         self.assertTrue(arc35.intersects(arc24))
-
-
-def suite():
-    """The test suite.
-    """
-    loader = unittest.TestLoader()
-    mysuite = unittest.TestSuite()
-    mysuite.addTest(loader.loadTestsFromTestCase(TestOverlap))
-    mysuite.addTest(loader.loadTestsFromTestCase(TestSphereGeometry))
-
-    return mysuite
-
-
-if __name__ == '__main__':
-    unittest.main()
